Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(175)

Unified Diff: pkg/analysis_server/lib/src/services/completion/imported_computer.dart

Issue 972193002: include library prefix suggestions when suggesting constructors (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: merge Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analysis_server/test/completion_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/services/completion/imported_computer.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/imported_computer.dart b/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
index c5ec1b61b2a6ab0339ca2809a85783eddc6a0192..4e025f3113136dd3e9d794e92c3621ed79df833d 100644
--- a/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
+++ b/pkg/analysis_server/lib/src/services/completion/imported_computer.dart
@@ -106,7 +106,7 @@ class _ImportedSuggestionBuilder extends ElementSuggestionBuilder
}
/**
* Add constructor suggestions from the cache.
* To reduce the number of suggestions sent to the client,
* filter the suggestions based upon the first character typed.
* If no characters are available to use for filtering,
@@ -119,6 +119,7 @@ class _ImportedSuggestionBuilder extends ElementSuggestionBuilder
}
DartCompletionCache cache = request.cache;
_addFilteredSuggestions(filterText, cache.importedConstructorSuggestions);
+ _addFilteredSuggestions(filterText, cache.libraryPrefixSuggestions);
}
/**
« no previous file with comments | « no previous file | pkg/analysis_server/test/completion_test.dart » ('j') | no next file with comments »
@@ -106,7 +106,7 @@ class _ImportedSuggestionBuilder extends ElementSuggestionBuilder
}
/**
- * Add constructor suggestions from the cache.
+ * Add constructor and library prefix suggestions from the cache.
* To reduce the number of suggestions sent to the client,
* filter the suggestions based upon the first character typed.

Powered by Google App Engine
This is Rietveld 408576698